@@ -19,7 +19,7 @@ def timer(time_length = False, message = False, variable = False):
     if variable:
       file = open(variable, "w")
       file.write("True")
-      flle.close()
+      file.close()
   t = threading.Thread(target=sub_timer)
   t.start()
 def wait(time_length = False, message = False):
